@@ -359,7 +359,7 @@ $lang['Open shortcut help'] = 'Ouvrir l\'aide des raccourcis';
 $lang['Error'] = 'Erreur';
 $lang['Please specify a valid mobile phone number'] = 'Veuillez entrer un numéro de mobile valide';
 $lang['Go to {0}'] = 'Aller à {0}';
-$lang['Please enter a name for your message. It should be unique.'] = 'Veuillz entrer un nom pour votre message. Il doit être unique.';
+$lang['Please enter a name for your message. It should be unique.'] = 'Veuillez entrer un nom pour votre message. Il doit être unique.';
 $lang['Are you sure? This will overwrite the previous message.'] = 'Êtes-vous sûr(e) ? Cela va écraser le message précédent.';
 $lang['PHP Frontend for gammu-smsd'] = 'PHP Frontend for gammu-smsd';
 $lang['Authors'] = 'Auteurs';
@@ -379,7 +379,7 @@ $lang['Theme'] = 'Thème';
 $lang['Background image'] = 'Image de fond';
 $lang['Ascending'] = 'Croissant';
 $lang['Descending'] = 'Décroissant';
-$lang['Value is too short.'] = 'La valeur estr trop courte.';
+$lang['Value is too short.'] = 'La valeur est trop courte.';
 $lang['Select group name'] = 'Sélectionner le nom du group';
 $lang['Uninstall'] = 'Désinstaller';
 $lang['Install'] = 'Installer';
